@@ -10,6 +10,9 @@
 #ifndef LIBC_BIONIC
 # define LIBC_BIONIC 3
 #endif
+#ifndef LIBC_MUSL
+# define LIBC_MUSL 4
+#endif
 #ifndef DEFAULT_LIBC
 # define DEFAULT_LIBC LIBC_GLIBC
 #endif
@@ -25,6 +28,24 @@
 #ifndef SUPPORT_SH4
 # define SUPPORT_SH4 1
 #endif
+#ifndef SUPPORT_SH1
+# define SUPPORT_SH1 1
+#endif
+#ifndef SUPPORT_SH2E
+# define SUPPORT_SH2E 1
+#endif
+#ifndef SUPPORT_SH4
+# define SUPPORT_SH4 1
+#endif
+#ifndef SUPPORT_SH4_SINGLE
+# define SUPPORT_SH4_SINGLE 1
+#endif
+#ifndef SUPPORT_SH2A
+# define SUPPORT_SH2A 1
+#endif
+#ifndef SUPPORT_SH2A_SINGLE
+# define SUPPORT_SH2A_SINGLE 1
+#endif
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
@@ -47,8 +68,5 @@
 #if defined IN_GCC && !defined GENERATOR_FILE
 # include "insn-modes.h"
 #endif
-#if defined IN_GCC && defined GENERATOR_FILE && !defined BITS_PER_UNIT
-#include "machmode.h"
-#endif
 # include "defaults.h"
 #endif /* GCC_TM_H */
